@@ -1,22 +1,24 @@
 from zope.interface import implements
 
-from twisted.internet.defer import inlineCallbacks, returnValue
+from twisted.internet.defer import inlineCallbacks
 
 from bravo.blocks import blocks
-from bravo.ibravo import IBuildHook, IDigHook
+from bravo.ibravo import IPostBuildHook, IDigHook
 from bravo.utilities.coords import split_coords
 
+from bravo.parameters import factory
+
 class Fallables(object):
     """
     Sometimes things should fall.
     """
 
-    implements(IBuildHook, IDigHook)
+    implements(IPostBuildHook, IDigHook)
 
     fallables = tuple()
     whitespace = (blocks["air"].slot,)
 
-    def dig_hook(self, factory, chunk, x, y, z, block):
+    def dig_hook(self, chunk, x, y, z, block):
         column = chunk.get_column(x, z)
         y = min(y - 1, 0)
 
@@ -43,12 +45,10 @@ class Fallables(object):
         chunk.set_column(x, z, column)
 
     @inlineCallbacks
-    def build_hook(self, factory, player, builddata):
-        bigx, smallx, bigz, smallz = split_coords(builddata.x, builddata.z)
+    def post_build_hook(self, player, coords, block):
+        bigx, smallx, bigz, smallz = split_coords(coords[0], coords[2])
         chunk = yield factory.world.request_chunk(bigx, bigz)
-        self.dig_hook(factory, chunk, smallx, builddata.y, smallz,
-            builddata.block)
-        returnValue((True, builddata))
+        self.dig_hook(chunk, smallx, coords[1], smallz, block)
 
     name = "fallables"
 
