@@ -372,7 +372,7 @@ class BetaProxyProtocol(BetaServerProtocol):
         self.username = container.username
 
         packet = make_packet("login", protocol=0, username="", seed=0,
-            dimension=0)
+            dimension="earth")
         self.transport.write(packet)
 
         url = urlunparse(("http", self.gateway, "/node/0/0/", None, None,
@@ -491,6 +491,9 @@ class BravoProtocol(BetaServerProtocol):
         packet += self.player.inventory.save_to_packet()
         self.transport.write(packet)
 
+        # Send weather.
+        self.transport.write(self.factory.vane.make_packet())
+
         self.send_initial_chunk_and_location()
 
         self.time_loop = LoopingCall(self.update_time)
@@ -555,7 +558,10 @@ class BravoProtocol(BetaServerProtocol):
         maxz = chunkz + chunk_radius + 1
 
         for x, z in product(xrange(minx, maxx), xrange(minz, maxz)):
+            if (x, z) not in self.chunks:
+                continue
             chunk = self.chunks[x, z]
+
             yieldables = [entity for entity in chunk.entities
                 if self.location.distance(entity.location) <= radius]
             for i in yieldables:
